sphinx: Python documentation generator
======================================

Description
-----------

Sphinx is a tool that makes it easy to create intelligent and beautiful
documentation for Python projects (or other documents consisting of
multiple reStructuredText sources), written by Georg Brandl. It was
originally created to translate the new Python documentation, but has
now been cleaned up in the hope that it will be useful to many other
projects.

License
-------

Modified BSD; see e.g. its egg-info file for other options


Upstream Contact
----------------

https://pypi.org/project/Sphinx/

